fn find_interleaved_doc_attr(attrs: &[Attribute]) -> Option<usize>Expand description
Returns the 1-based line number of the first non-doc attribute that interrupts
a doc-comment stream, or None if no such interruption exists.
An interruption is: at least one #[doc = ...] attr has been seen, then a
non-doc attribute appears, then at least one more #[doc = ...] attr follows.